import { HawkmoonUtility } from "./hawkmoon-utility.js";

export class HawkmoonRollDialog extends Dialog {

  /* -------------------------------------------- */
  static async create(actor, rollData ) {

    let options = { classes: ["HawkmoonDialog"], width: 340, height: 'fit-content', 'z-index': 99999 };
    let html = await renderTemplate('systems/fvtt-hawkmoon-cyd/templates/roll-dialog-generic.html', rollData);

    return new HawkmoonRollDialog(actor, rollData, html, options );
  }

  /* -------------------------------------------- */
  constructor(actor, rollData, html, options, close = undefined) {
    let conf = {
      title: "Test de Capacité",
      content: html,
      buttons: { 
        rolld10: {
            icon: '<i class="fas fa-check"></i>',
            label: "Lancer 1d10",
            callback: () => { this.roll("d10") } 
          },
          rolld20: {
            icon: '<i class="fas fa-check"></i>',
            label: "Lancer 1d20",
            callback: () => { this.roll("d20") } 
          },
          cancel: {
            icon: '<i class="fas fa-times"></i>',
            label: "Annuler",
            callback: () => { this.close() }
        } },
      close: close
    }

    super(conf, options);

    this.actor = actor
    this.rollData = rollData
  }

  /* -------------------------------------------- */
  roll ( dice) {
    this.rollData.mainDice = dice
    HawkmoonUtility.rollHawkmoon( this.rollData )
  }


  /* -------------------------------------------- */
  activateListeners(html) {
    super.activateListeners(html);

    var dialog = this;
    function onLoad() {
    }
    $(function () { onLoad(); });
    
    html.find('#modificateur').change(async (event) =>  {
      this.rollData.modificateur = Number(event.currentTarget.value)
    })
    html.find('#difficulte').change(async (event) =>  {
      this.rollData.difficulte = Number(event.currentTarget.value)
    })
    html.find('#attrKey').change(async (event) =>  {
      this.rollData.attrKey = String(event.currentTarget.value)
    })    
    html.find('#select-maitrise').change(async (event) =>  {
      this.rollData.maitriseId = String(event.currentTarget.value)
    })
    html.find('#competence-talents').change((event) => {
      this.rollData.selectedTalents = $('#competence-talents').val()
    })
  }
}